W

Type Alias W 

pub type W = W<BF_MATRIX_CTRL_SPEC>;
Register BF_MATRIX_CTRL writer

Aliased Type

pub struct W { /* private fields */ }

Implementations

Source

impl W

pub fn bf_tail_pixen_pulse_tl( &mut self, ) -> BF_TAIL_PIXEN_PULSE_TL_W<'_, BF_MATRIX_CTRL_SPEC>

Bits 0:7 - matrix tail pixen low level threshold, should not to large to prevent expanding to next frame, only reg_bf_tail_pixen_pulse_th!=0 and reg_bf_tail_pixen_pulse_tl!=0 and reg_bf_tail_pixen_pulse_th < reg_bf_tail_pixen_pulse_tl will enable tail pulse function

pub fn bf_tail_pixen_pulse_th( &mut self, ) -> BF_TAIL_PIXEN_PULSE_TH_W<'_, BF_MATRIX_CTRL_SPEC>

Bits 8:15 - matrix tail pixen high level threshold, must < hnum-1, only reg_bf_tail_pixen_pulse_th!=0 and reg_bf_tail_pixen_pulse_tl!=0 and reg_bf_tail_pixen_pulse_th < reg_bf_tail_pixen_pulse_tl will enable tail pulse function

pub fn bf_padding_data(&mut self) -> BF_PADDING_DATA_W<'_, BF_MATRIX_CTRL_SPEC>

Bits 16:23 - this field configures bf matrix padding data

pub fn bf_padding_mode(&mut self) -> BF_PADDING_MODE_W<'_, BF_MATRIX_CTRL_SPEC>

Bit 24 - this bit configures the padding mode of bf matrix. 0: use pixel in image to do padding 1: use reg_padding_data to do padding