Control and configuration registers
Structs
- TX_
CTRL_ SPEC - Control and configuration registers
Type Aliases
- R
- Register
TX_CTRLreader - TX_
COND_ MODE_ R - Field
TX_COND_MODEreader - write this bit to specify the LOOP instruction condition mode of bitscrambler tx core, 0: use the little than operator to get the condition, 1: use not equal operator to get the condition - TX_
COND_ MODE_ W - Field
TX_COND_MODEwriter - write this bit to specify the LOOP instruction condition mode of bitscrambler tx core, 0: use the little than operator to get the condition, 1: use not equal operator to get the condition - TX_
ENA_ R - Field
TX_ENAreader - write this bit to enable the bitscrambler tx - TX_
ENA_ W - Field
TX_ENAwriter - write this bit to enable the bitscrambler tx - TX_
EOF_ MODE_ R - Field
TX_EOF_MODEreader - write this bit to ser the bitscrambler tx core EOF signal generating mode which is combined with reg_bitscrambler_tx_tailing_bits, 0: counter by read dma fifo, 0 counter by write peripheral buffer - TX_
EOF_ MODE_ W - Field
TX_EOF_MODEwriter - write this bit to ser the bitscrambler tx core EOF signal generating mode which is combined with reg_bitscrambler_tx_tailing_bits, 0: counter by read dma fifo, 0 counter by write peripheral buffer - TX_
FETCH_ MODE_ R - Field
TX_FETCH_MODEreader - write this bit to set the bitscrambler tx core fetch instruction mode, 0: prefetch by reset, 1: fetch by instrutions - TX_
FETCH_ MODE_ W - Field
TX_FETCH_MODEwriter - write this bit to set the bitscrambler tx core fetch instruction mode, 0: prefetch by reset, 1: fetch by instrutions - TX_
FIFO_ RST_ W - Field
TX_FIFO_RSTwriter - write this bit to reset the bitscrambler tx fifo - TX_
HALT_ MODE_ R - Field
TX_HALT_MODEreader - write this bit to set the bitscrambler tx core halt mode when tx_halt is set, 0: wait write data back done, , 1: ignore write data back - TX_
HALT_ MODE_ W - Field
TX_HALT_MODEwriter - write this bit to set the bitscrambler tx core halt mode when tx_halt is set, 0: wait write data back done, , 1: ignore write data back - TX_
HALT_ R - Field
TX_HALTreader - write this bit to halt the bitscrambler tx core - TX_
HALT_ W - Field
TX_HALTwriter - write this bit to halt the bitscrambler tx core - TX_
PAUSE_ R - Field
TX_PAUSEreader - write this bit to pause the bitscrambler tx core - TX_
PAUSE_ W - Field
TX_PAUSEwriter - write this bit to pause the bitscrambler tx core - TX_
RD_ DUMMY_ R - Field
TX_RD_DUMMYreader - write this bit to set the bitscrambler tx core read data mode when EOF received.0: wait read data, 1: ignore read data - TX_
RD_ DUMMY_ W - Field
TX_RD_DUMMYwriter - write this bit to set the bitscrambler tx core read data mode when EOF received.0: wait read data, 1: ignore read data - W
- Register
TX_CTRLwriter