pub type R = R<LOCK_ADDR_SPEC>;
Register LOCK_ADDR reader
LOCK_ADDR
pub struct R { /* private fields */ }
Bits 0:31 - Those bits are used to configure the start virtual address of the lock/unlock operation, which should be used together with CACHE_LOCK_SIZE_REG